This type is governed by futile.paradigm. Below are the supported function
variants.create.TawnyPortfolio(T, returns, window = 90)
create.TawnyPortfolio(T, symbols, window = 90, obs = 150)
Creates a benchmark portfolio to compare with the actual portfolio.
create.BenchmarkPortfolio(T, symbol, window = 90, obs = 150, end = Sys.Date(), ...)
Calculates portfolio returns based on the weights calculated.
create.PortfolioReturns(T, p, weights), p is a TawnyPortfolio
create.PortfolioReturns(T, h, weights), h is an AssetReturns object or zoo
'start' and 'end' operate on a TawnyPortfolio to return the start and end
dates, respectively, of the portfolio.
'rollapply' is the implementation of the zoo function for a TawnyPortfolio. The
'window_at' function supports this by providing a window of the portfolio for
the given index.